--Set up traditional data set

CREATE TABLE PoliceData.LocalCrimeReport
(
	LocalCrimeReportingCode VARCHAR(5) NOT NULL,
	LocalCrimeReportingDescription VARCHAR(60) NOT NULL
);

ALTER TABLE PoliceData.LocalCrimeReport ADD CONSTRAINT [PK_LocalCrimeReport] PRIMARY KEY CLUSTERED(LocalCrimeReportingCode);

GO

INSERT INTO PoliceData.LocalCrimeReport
(
	LocalCrimeReportingCode,
	LocalCrimeReportingDescription
)
SELECT DISTINCT
	[LCR],
	[LCR DESC]
FROM
	Import.PoliceIncidents;
	
GO

CREATE TABLE PoliceData.Incident
(
	IncidentID INT IDENTITY(1,1) NOT NULL,
	IncidentNumber VARCHAR(19) NOT NULL,
	LocalCrimeReportingCode VARCHAR(5) NOT NULL,
	IncidentDate DATETIME NOT NULL,
	Beat INT NOT NULL,
	Location GEOGRAPHY NULL
);

ALTER TABLE PoliceData.Incident ADD CONSTRAINT [PK_Incident] PRIMARY KEY CLUSTERED(IncidentID);
ALTER TABLE PoliceData.Incident ADD CONSTRAINT [UKC_Incident] UNIQUE(IncidentNumber);
ALTER TABLE PoliceData.Incident ADD CONSTRAINT [FK_Incident_LocalCrimeReportingCode] FOREIGN KEY(LocalCrimeReportingCode) REFERENCES [PoliceData].[LocalCrimeReport](LocalCrimeReportingCode);

INSERT INTO PoliceData.Incident
(
	IncidentNumber,
	LocalCrimeReportingCode,
	IncidentDate,
	Beat,
	Location
)
SELECT
	[INC NO],
	[LCR],
	[INC DATETIME],
	[BEAT],
	CASE WHEN LOCATION <> '' THEN geography::STPointFromText('POINT' + REPLACE(LOCATION, ',', ' '), 4326) ELSE NULL END
FROM
	Import.PoliceIncidents;