--Set up In-Memory data set

ALTER DATABASE OpenData
ADD FILEGROUP OpenDataInMemoryOLTP 
CONTAINS MEMORY_OPTIMIZED_DATA;

GO

ALTER DATABASE OpenData
ADD FILE
(
	NAME = OpenDataInMemoryOLTPFile,
	FILENAME = N'C:\SQL\Data\OpenDataInMemoryOLTPFile'
) TO FILEGROUP OpenDataInMemoryOLTP;

GO

CREATE TABLE PoliceData.Location
(
	LocationID INT IDENTITY(1,1) NOT NULL,
	Location GEOGRAPHY NOT NULL
);

ALTER TABLE PoliceData.Location ADD CONSTRAINT [PK_Location] PRIMARY KEY CLUSTERED(LocationID);

GO

WITH records AS
(
	SELECT 
		geography::STPointFromText('POINT' + REPLACE(LOCATION, ',', ' '), 4326) as Location
	FROM
		Import.PoliceIncidents
	WHERE
		LOCATION <> ''
)
INSERT INTO PoliceData.Location
(
	Location
)
SELECT DISTINCT
	CAST(Location AS varbinary(512)) 
FROM 
	records;

GO

CREATE TABLE PoliceData.IncidentInMemory
(
	IncidentID INT NOT NULL PRIMARY KEY NONCLUSTERED HASH WITH (BUCKET_COUNT = 500000),
	IncidentNumber VARCHAR(19) COLLATE Latin1_General_100_BIN2 NOT NULL,
	LocalCrimeReportingCode VARCHAR(5) COLLATE Latin1_General_100_BIN2 NOT NULL,
	IncidentDate DATETIME NOT NULL,
	Beat INT NOT NULL,
	LocationID INT NULL,

	INDEX [IX_IncidentInMemory_LocalCrimeReportingCode] NONCLUSTERED (LocalCrimeReportingCode),
	INDEX [IX_IncidentInMemory_IncidentDate] NONCLUSTERED(IncidentDate)
)
WITH
(
	MEMORY_OPTIMIZED = ON,
	DURABILITY = SCHEMA_AND_DATA
);

GO

CREATE SEQUENCE [PoliceData].IncidentInMemorySequence
	AS INT
	START WITH 1
	INCREMENT BY 1
	NO CYCLE
	NO CACHE;

GO

INSERT INTO PoliceData.IncidentInMemory
(
	IncidentID,
	IncidentNumber,
	LocalCrimeReportingCode,
	IncidentDate,
	Beat,
	LocationID
)
SELECT
	NEXT VALUE FOR [PoliceData].IncidentInMemorySequence,
	p.[INC NO],
	p.[LCR],
	p.[INC DATETIME],
	p.[BEAT],
	l.LocationID
FROM
	Import.PoliceIncidents p
	LEFT OUTER JOIN PoliceData.Location l 
		ON CAST(l.Location AS VARBINARY(512)) = CASE WHEN p.LOCATION <> '' THEN CAST(geography::STPointFromText('POINT' + REPLACE(p.LOCATION, ',', ' '), 4326) AS VARBINARY(512)) ELSE NULL END;