--Basic query:  grab data from a table based on an indexed column.
--Note that we do not have any bookmark lookups.
--This implies that we don't really need INCLUDE columns or
--covering indexes and can focus on the WHERE clause.
SELECT 
	* 
FROM 
	PoliceData.IncidentInMemory
WHERE 
	LocalCrimeReportingCode = '51CN';

--Add another filter and...the optimizer picks the wrong index!
--Filtering against 45K rows instead of 3K leads to a terrible plan.
--Note:  even with a terrible plan, this is still a fast query.
SELECT 
	*
FROM 
	PoliceData.IncidentInMemory 
WHERE
	LocalCrimeReportingCode = '51CN' 
	AND IncidentDate BETWEEN '2008-06-01' AND '2009-06-01';

--We can force indexes, which in this case is a good idea.
--The filter (filtering dates) is a tiny expense.
SELECT 
	*
FROM 
	PoliceData.IncidentInMemory WITH(INDEX([IX_IncidentInMemory_LocalCrimeReportingCode]))
WHERE
	LocalCrimeReportingCode = '51CN' 
	AND IncidentDate BETWEEN '2008-06-01' AND '2009-06-01';